"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = __importDefault(require("../"));
const errors_1 = require("../errors");
function getContext(query) {
    return {
        text: query,
        rawText: query
    };
}
const analyzer = new __1.default();
describe('Analyzer', () => {
    describe('Syntax Errors', () => {
        it('throws empty query error for empty queries', () => {
            const context = getContext('');
            expect(() => analyzer.analyze(context)).toThrow(errors_1.EmptyQueryError);
        });
        it('throws generic syntax error', () => {
            const context = getContext('SELECT * FROM users WHERE');
            expect(() => analyzer.analyze(context)).toThrow(errors_1.SyntaxErrorGeneric);
        });
        it('throws keyword syntax error', () => {
            const context = getContext('CREATE TABLE foo (id int boolean boolean)');
            expect(() => analyzer.analyze(context)).toThrow(errors_1.SyntaxErrorKeyword);
        });
        it('throws not keyword syntax error', () => {
            const context = getContext('SELECT * FRM');
            expect(() => analyzer.analyze(context)).toThrow(errors_1.SyntaxErrorNotKeyword);
        });
    });
    describe('Semantic Errors', () => {
        it('does not throw if there is no schema', () => {
            const context = getContext('SELECT * FROM users');
            expect(() => analyzer.analyze(context)).not.toThrow();
        });
        it('throws if received table does not exist in schema', () => {
            const context = getContext('SELECT * FROM users');
            const tables = [{ name: 'not-users', columns: [] }];
            expect(() => analyzer.analyze(context, tables)).toThrow(errors_1.SemanticErrorBadTable);
        });
        it('throws if received column does not exist in schema', () => {
            const context = getContext('SELECT id FROM users');
            const tables = [{ name: 'users', columns: [] }];
            expect(() => analyzer.analyze(context, tables)).toThrow(errors_1.SemanticErrorBadColumn);
        });
        it('throws if expected column type does not match received column type', () => {
            const context = getContext('SELECT id FROM users WHERE id = 1');
            const column = { name: 'id', tsType: 'string', sqlType: '', optional: false };
            const tables = [{ name: 'users', columns: [column] }];
            expect(() => analyzer.analyze(context, tables)).toThrow(errors_1.SemanticErrorBadColumnValue);
        });
        it('does not throw if expected column type matches received column type', () => {
            const context = getContext('SELECT id FROM users WHERE id = "some-id"');
            const column = { name: 'id', tsType: 'string', sqlType: '', optional: false };
            const tables = [{ name: 'users', columns: [column] }];
            expect(() => analyzer.analyze(context, tables)).not.toThrow();
        });
    });
});
//# sourceMappingURL=analyzer.test.js.map