"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const get_substitutions_1 = __importDefault(require("../get-substitutions"));
const ts_morph_1 = require("ts-morph");
const typescript_1 = __importDefault(require("typescript"));
const project = new ts_morph_1.Project({
    compilerOptions: {
        target: ts_morph_1.ScriptTarget.ES2020
    }
});
function testSubstitution(text) {
    const sourceFile = project.createSourceFile('', text, { overwrite: true });
    const checker = project.getTypeChecker();
    const node = sourceFile.getDescendantsOfKind(typescript_1.default.SyntaxKind.TemplateExpression);
    if (!node.length) {
        throw new Error('No template expression found.');
    }
    return get_substitutions_1.default(checker.compilerObject, node[0].compilerNode);
}
describe('getSubstitutions', () => {
    it('substitutes null for ${null}', () => {
        const substitution = testSubstitution('`${null}`');
        expect(substitution).toBe('null   ');
    });
    it('substitutes 11111 for ${30}', () => {
        const substitution = testSubstitution('`${30}`');
        expect(substitution).toBe('11111');
    });
    it('substitutes "xxxxxxxxx" for ${"steven"}', () => {
        const substitution = testSubstitution('`${"steven"}`');
        expect(substitution).toBe('"xxxxxxxxx"');
    });
    it('substitutes true    for ${true}', () => {
        const substitution = testSubstitution('`${true}`');
        expect(substitution).toBe('true   ');
    });
    it('substitutes true    for ${false}', () => {
        const substitution = testSubstitution('`${false}`');
        expect(substitution).toBe('true    ');
    });
});
//# sourceMappingURL=get-substitutions.test.js.map